@@ -40,18 +40,18 @@ names(haplo_db_D2_21)[which(names(haplo_db_D2_21)=='IGHD2-21_01')] <- "AnchorJ03
 names(haplo_db_J6)[which(names(haplo_db_J6)=='IGHJ6_02')] <- "AnchorJ02D02"
 names(haplo_db_D2_21)[which(names(haplo_db_D2_21)=='IGHD2-21_02')] <- "AnchorJ02D02"
 
-# Subseting the haplo_db_J6 dataset to include only the V genes
+# subsetting the haplo_db_J6 dataset to include only the V genes
 haplo_db_J6 <- haplo_db_J6[grep('IGHV',haplo_db_J6$gene),]
 
-# Combining the datasets rowwise
+# Combining the datasets row wise
 haplo_comb <- rbind(haplo_db_J6,haplo_db_D2_21)
 
 ## ---- eval=TRUE, warning=FALSE, fig.width=14, fig.height=6--------------------
-# Plot the haplotype inferred dendogram
+# Plot the haplotype inferred deprogram
 hapDendo(haplo_comb)
 
 ## ---- cache = T, eval=TRUE, warning=FALSE, fig.width=12, fig.height=12--------
-# Removing the individual I5_FR1 with the paritial V coverage sequence.
+# Removing the individual I5_FR1 with the partial V coverage sequence.
 clip_dbs <- samples_db[samples_db$subject!='I5_FR2', ]
 
 # Inferred haplotype summary table
@@ -61,7 +61,7 @@ haplo_db <- createFullHaplotype(clip_dbs, toHap_col=c("v_call","d_call"),
 p.list <- hapHeatmap(haplo_db)
 
 # The function return a list with the plot and the optimal width and height
-# we can use both parametrs to render the plot to the desired size.
+# we can use both parameters to render the plot to the desired size.
 width <- p.list$width
 height <- p.list$height
 
@@ -71,7 +71,7 @@ height <- p.list$height
 p.list$p
 
 ## ---- eval=TRUE, warning=FALSE------------------------------------------------
-# Infering double choromosome deletions
+# Inferring double chromosome deletions
 del_binom_db <- deletionsByBinom(clip_dbs)
 head(del_binom_db)
 
@@ -104,7 +104,7 @@ haplo_db <- createFullHaplotype(clip_db, toHap_col=c("v_call","d_call"),
 
 ## ---- eval=TRUE, warning=FALSE------------------------------------------------
 # Generate interactive haplotype plot
-p <- plotHaplotype(haplo_db, html_output = TRUE)
+p <- plotHaplotype(hap_table = haplo_db, html_output = TRUE)
 
 ## ---- cache=FALSE, eval=FALSE, warning=FALSE----------------------------------
 #  # Saving the plot to html output
@@ -118,7 +118,7 @@ p <- plotHaplotype(haplo_db, html_output = TRUE)
 # Detecting non reliable genes
 nonReliable_Vgenes <- nonReliableVGenes(samples_db)
 
-# Infering double chromosome deletion
+# Inferring double chromosome deletion
 del_binom_db <- deletionsByBinom(samples_db, nonReliable_Vgenes = nonReliable_Vgenes)
 
 # Inferred haplotype summary table for multiple subjects
